## Sampling and Assignment

### Description

A list of 100 random names generated by <a href="http://listofrandomnames.com" target="_blank">listofrandomnames.com</a>. The dataset includes 50 male and 50 female names. The dataset is used to illustrate simple random sampling and random assignment to treaments in an experimental design.

### Variables

A data frame with 100 observations on 2 variables

- Names = Name
- Gender = Gender